<?php
/*
 * This file is part of EC-CUBE
 *
 * Copyright(c) 2000-2011 LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

// {{{ requires
require_once CLASS_PATH . 'pages/shopping/LC_Page_Shopping_Payment.php';

/**
 * 支払い方法選択 のページクラス(拡張).
 *
 * LC_Page_Shopping_Payment をカスタマイズする場合はこのクラスを編集する.
 *
 * @package Page
 * @author LOCKON CO.,LTD.
 * @version $Id: LC_Page_Shopping_Payment_Ex.php 20764 2011-03-22 06:26:40Z nanasess $
 */
class LC_Page_Shopping_Payment_Ex extends LC_Page_Shopping_Payment {

    // }}}
    // {{{ functions

    /**
     * Page を初期化する.
     *
     * @return void
     */
    function init() {
        parent::init();
    }

    /**
     * Page のプロセス.
     *
     * @return void
     */
    function process() {
        global $objCampaignSess;

        $objView = new SC_SiteView();
        $objSiteSess = new SC_SiteSession();
        $objCartSess = new SC_CartSession();
        $objCampaignSess = new SC_CampaignSession();
        $objDb = new SC_Helper_DB_Ex();
        $this->objCustomer = new SC_Customer();
        $objSiteInfo = $objView->objSiteInfo;
        $arrInfo = $objSiteInfo->data;
        $this->tpl_mainpage = MODULE_PATH."mdl_dchk/templates/pc/payment.tpl";

        // パラメータ管理クラス
        $this->objFormParam = new SC_FormParam();
        // パラメータ情報の初期化
        $this->lfInitParam();
        // POST値の取得
        $this->objFormParam->setParam($_POST);

        // ユーザユニークIDの取得と購入状態の正当性をチェック
        $uniqid = SC_Utils_Ex::sfCheckNormalAccess($objSiteSess, $objCartSess);
        // ユニークIDを引き継ぐ
        $this->tpl_uniqid = $uniqid;

        // 会員ログインチェック
        if($this->objCustomer->isLoginSuccess()) {
            $this->tpl_login = '1';
            $this->tpl_user_point = $this->objCustomer->getValue('point');
            //戻り先URL
            $this->tpl_back_url = URL_DELIV_TOP;
        } else {
            $this->tpl_back_url = URL_SHOP_TOP . "?from=nonmember";
        }

        // 一時受注テーブルの読込
        $arrOrderTemp = $objDb->sfGetOrderTemp($uniqid);
        //不正遷移チェック（正常に受注情報が格納されていない場合は一旦カート画面まで戻す）
        if (!$arrOrderTemp){
            $this->sendRedirect($this->getLocation(URL_CART_TOP));
            exit;
        }
        // 金額の取得 (購入途中で売り切れた場合にはこの関数内にてその商品の個数が０になる)
        $objDb->sfTotalCart($this, $objCartSess, $arrInfo);

        if (empty($arrData)) $arrData = array();
        $this->arrData = $objDb->sfTotalConfirm($arrData, $this, $objCartSess, $arrInfo);

        // カート内の商品の売り切れチェック
        $objCartSess->chkSoldOut($objCartSess->getCartList());

        if (!isset($_POST['mode'])) $_POST['mode'] = "";

        switch($_POST['mode']) {
        case 'confirm':
            // 入力値の変換
            $this->objFormParam->convParam();
            $this->arrErr = $this->lfCheckError($this->arrData );
            // 入力エラーなし
            if(count($this->arrErr) == 0) {
                if($_POST["use_regcard"] == 1){
                    $_SESSION["use_regcard"] = 1;
                }else{
                    $_SESSION["use_regcard"] = 0;
                }
                // DBへのデータ登録
                $this->lfRegistData($uniqid);
                // 正常に登録されたことを記録しておく
                $objSiteSess->setRegistFlag();
                // 確認ページへ移動
                $this->sendRedirect($this->getLocation(URL_SHOP_CONFIRM, array(), true));
                exit;
            }else{
                // ユーザユニークIDの取得
                $uniqid = $objSiteSess->getUniqId();
                // 受注一時テーブルからの情報を格納
                $this->lfSetOrderTempData($uniqid);
            }
            break;
        // 前のページに戻る
        case 'return':
            // 非会員の場合
            // 正常な推移であることを記録しておく
            $objSiteSess->setRegistFlag();
            $this->sendRedirect(URL_SHOP_TOP);
            exit;
            break;
        // 支払い方法が変更された場合
        case 'payment':
            // ここのbreakは、意味があるので外さないで下さい。
            break;
        default:
            // 受注一時テーブルからの情報を格納
            $this->lfSetOrderTempData($uniqid);
            break;
        }

        // 店舗情報の取得
        $arrInfo = $objSiteInfo->data;
        // 購入金額の取得得
        $total_pretax = $objCartSess->getAllProductsTotal($arrInfo);
        // 支払い方法の取得
        $this->arrPayment = $this->lfGetPayment($total_pretax);
        // 支払い方法の画像があるなしを取得（$img_show true:ある false:なし）
        $this->img_show = $this->lfGetImgShow($this->arrPayment);
        // お届け時間の取得
        $arrRet = $objDb->sfGetDelivTime($this->objFormParam->getValue('payment_id'));
        $this->arrDelivTime = SC_Utils_Ex::sfArrKeyValue($arrRet, 'time_id', 'deliv_time');

        // お届け日一覧の取得
        $this->arrDelivDate = $this->lfGetDelivDate();

        $this->arrForm = $this->objFormParam->getFormParamList();

        $objView->assignobj($this);
        // フレームを選択(キャンペーンページから遷移なら変更)
        $objCampaignSess->pageView($objView);
    }

    /**
     * Page のプロセス(モバイル).
     *
     * @return void
     */
    function mobileProcess() {
        $objView = new SC_MobileView();
        $objSiteSess = new SC_SiteSession();
        $objCartSess = new SC_CartSession();
        $this->objCustomer = new SC_Customer();
        $objDb = new SC_Helper_DB_Ex();
        $objSiteInfo = $objView->objSiteInfo;
        $arrInfo = $objSiteInfo->data;
        $this->tpl_mainpage = MODULE_PATH."mdl_dchk/templates/mobile/payment.tpl";

        // パラメータ管理クラス
        $this->objFormParam = new SC_FormParam();
        // パラメータ情報の初期化
        $this->lfInitParam();
        // POST値の取得
        $this->objFormParam->setParam($_POST);

        // ユーザユニークIDの取得と購入状態の正当性をチェック
        $uniqid = SC_Utils_Ex::sfCheckNormalAccess($objSiteSess, $objCartSess);
        // ユニークIDを引き継ぐ
        $this->tpl_uniqid = $uniqid;

        // 会員ログインチェック
        if($this->objCustomer->isLoginSuccess(true)) {
            $this->tpl_login = '1';
            $this->tpl_user_point = $this->objCustomer->getValue('point');
        }

        // 一時受注テーブルの読込
        $arrOrderTemp = $objDb->sfGetOrderTemp($uniqid);
        //不正遷移チェック（正常に受注情報が格納されていない場合は一旦カート画面まで戻す）
        if (!$arrOrderTemp){
            $this->sendRedirect($this->getLocation(MOBILE_URL_CART_TOP));
            exit;
        }
        // 金額の取得 (購入途中で売り切れた場合にはこの関数内にてその商品の個数が０になる)
        $objDb->sfTotalCart($this, $objCartSess, $arrInfo);
        if (empty($arrData)) $arrData = array();
        $this->arrData = $objDb->sfTotalConfirm($arrData, $this, $objCartSess, $arrInfo);

        // カート内の商品の売り切れチェック
        $objCartSess->chkSoldOut($objCartSess->getCartList(), true);

        if (!isset($_POST['mode'])) $_POST['mode'] = "";

        // 戻るボタンの処理
        if (!empty($_POST['return'])) {
            switch ($_POST['mode']) {
            case 'confirm':
                $_POST['mode'] = 'payment';
                break;
            default:
                // 正常な推移であることを記録しておく
                $objSiteSess->setRegistFlag();
                $this->sendRedirect(MOBILE_URL_SHOP_TOP, true);
                exit;
            }
        }

        switch($_POST['mode']) {
            // 支払い方法指定 → お届け日時指定
        case 'deliv_date':
            // 入力値の変換
            $this->objFormParam->convParam();
            $this->arrErr = $this->lfCheckError($this->arrData);
            if (!isset($this->arrErr['payment_id'])) {
                // 支払い方法の入力エラーなし
                if($_POST["use_regcard"] == 1){
                    $_SESSION["use_regcard"] = 1;
                }else{
                    $_SESSION["use_regcard"] = 0;
                }
                $this->tpl_mainpage = 'shopping/deliv_date.tpl';
                $this->tpl_title = "お届け日時指定";
                break;
            } else {
                // ユーザユニークIDの取得
                $uniqid = $objSiteSess->getUniqId();
                // 受注一時テーブルからの情報を格納
                $this->lfSetOrderTempData($uniqid);
            }
            break;
        case 'confirm':
            // 入力値の変換
            $this->objFormParam->convParam();
            $this->arrErr = $this->lfCheckError($this->arrData );
            // 入力エラーなし
            if(count($this->arrErr) == 0) {
                // DBへのデータ登録
                $this->lfRegistData($uniqid);
                // 正常に登録されたことを記録しておく
                $objSiteSess->setRegistFlag();
                // 確認ページへ移動
                $this->sendRedirect($this->getLocation(MOBILE_URL_SHOP_CONFIRM), true);
                exit;
            }else{
                // ユーザユニークIDの取得
                $uniqid = $objSiteSess->getUniqId();
                // 受注一時テーブルからの情報を格納
                $this->lfSetOrderTempData($uniqid);
                if (!isset($this->arrErr['payment_id'])) {
                    // 支払い方法の入力エラーなし
                    $this->tpl_mainpage = 'shopping/deliv_date.tpl';
                    $this->tpl_title = "お届け日時指定";
                }
            }
            break;
            // 前のページに戻る
        case 'return':
            // 非会員の場合
            // 正常な推移であることを記録しておく
            $objSiteSess->setRegistFlag();
            $this->sendRedirect(MOBILE_URL_SHOP_TOP, true);
            exit;
            break;
            // 支払い方法が変更された場合
        case 'payment':
            // ここのbreakは、意味があるので外さないで下さい。
            break;
        default:
            // 受注一時テーブルからの情報を格納
            $this->lfSetOrderTempData($uniqid);
            break;
        }

        // 店舗情報の取得
        $arrInfo = $objSiteInfo->data;
        // 購入金額の取得得
        $total_pretax = $objCartSess->getAllProductsTotal($arrInfo);
        // 支払い方法の取得
        $this->arrPayment = $this->lfGetPayment($total_pretax);
        // お届け時間の取得
        $arrRet = $objDb->sfGetDelivTime($this->objFormParam->getValue('payment_id'));
        $this->arrDelivTime = SC_Utils_Ex::sfArrKeyValue($arrRet, 'time_id', 'deliv_time');

        // お届け日一覧の取得
        $this->arrDelivDate = $this->lfGetDelivDate();

        $this->arrForm = $this->objFormParam->getFormParamList();

        $objView->assignobj($this);
        $objView->display(SITE_FRAME);
    }



    /**
     * デストラクタ.
     *
     * @return void
     */
    function destroy() {
        parent::destroy();
    }
}
?>
